@@ -255,7 +255,7 @@ module GraphQL
               return
             else
               arguments = scalar_method_names.map { |m| "#{m}: nil"} +
-                @children_methods.keys.map { |m| "#{m}: []" }
+                @children_methods.keys.map { |m| "#{m}: NO_CHILDREN" }
 
               assignments = scalar_method_names.map { |m| "@#{m} = #{m}"} +
                 @children_methods.keys.map { |m| "@#{m} = #{m}.freeze" }
